@@ -2075,7 +2075,6 @@ func TestNewAppListAndSearch(t *testing.T) {
 	for _, test := range tests {
 		stdout, stderr := PrepareAppConfig(test.options.Config)
 		test.options.Action.Out, test.options.ErrOut = stdout, stderr
-		test.options.BaseName = "oc"
 		test.options.CommandName = "new-app"
 
 		err := test.options.RunNewApp()
@@ -2492,7 +2491,7 @@ func (c *NewAppFakeImageStreams) Patch(ctx context.Context, name string, pt ktyp
 	return c.proxy.Patch(ctx, name, pt, data, opts, subresources...)
 }
 
-func (c *NewAppFakeImageStreams) Secrets(ctx context.Context, imageStreamName string, opts metav1.GetOptions) (result *corev1.SecretList, err error) {
+func (c *NewAppFakeImageStreams) Secrets(ctx context.Context, imageStreamName string, opts metav1.GetOptions) (result *imagev1.SecretList, err error) {
 	return c.proxy.Secrets(ctx, imageStreamName, opts)
 }
 
